@@ -1,8 +1,8 @@
 from aperturedb import Connector
 # This file containts information on to access the server
 
-DB_HOST     = "localhost"
-DB_PORT     = 55557
+DB_HOST     = "aperturedb"
+DB_PORT     = 55555
 DB_USER     = "admin"
 DB_PASSWORD = "admin"
 
